require 'studio_game/game'

module StudioGame
  describe Game do

    before do
      @game = Game.new
      @initial_health = 100
      @player = Player.new 'moe', @initial_health
      @game.add_player @player
    end

    context 'should w00t a player if a high number is rolled' do
      it 'should play one round if no rounds provided' do
        allow_any_instance_of(Die).to receive(:roll).and_return 5
        @game.play
        expect(@player.health).to eq @initial_health + 15
      end

      it 'should play the rounds provided' do
        rounds = 2
        allow_any_instance_of(Die).to receive(:roll).and_return 5
        @game.play rounds
        expect(@player.health).to eq @initial_health + 15 * rounds
      end

    end

    it 'should do nothing to a player if a medium number is rolled' do
      allow_any_instance_of(Die).to receive(:roll).and_return 3
      @game.play
      expect(@player.health).to eq @initial_health
    end

    it 'should blam a player if a low number is rolled' do
      allow_any_instance_of(Die).to receive(:roll).and_return 1
      @game.play
      expect(@player.health).to eq @initial_health - 10
    end

    it 'assigns a treasure for points during a turn' do
      game = Game.new
      player = Player.new 'moe'
      game.add_player player
      game.play 1
      expect(player.points).not_to eq 0
    end
  end
end
