require 'studio_game/player'
require 'studio_game/treasure_trove'


module StudioGame
# rubocop:disable BlockLength
  describe Player do
    before do
      @player = Player.new 'shemp'
      $stdout = StringIO.new
    end

    it 'has a capitalized name' do
      expect(@player.name).to eq 'Shemp'
    end

    it 'has an initial health' do
      expect(@player.health).to eq 100
    end

    it 'has a string representation' do
      expected = "I'm Shemp with health = 100, points = 0, and score = 100."
      expect(@player.to_s).to eq expected
    end

    it 'computes a score as the sum of its health and points' do
      treasure = TreasureTrove::Treasure.new :hammer, 50
      2.times { @player.found_treasure treasure }
      expect(@player.score).to eq 100 + 2 * 50
    end

    it 'increases health by 15 when w00ted' do
      @player.w00t
      expect(@player.health).to eq 115
    end

    it 'decreases health by 10 when blammed' do
      @player.blam
      expect(@player.health).to eq 90
    end

    it 'computes points as the sum of all treasure points' do
      expect(@player.points).to eq 0

      @player.found_treasure TreasureTrove::Treasure.new :hammer, 50
      expect(@player.points).to eq 50

      @player.found_treasure TreasureTrove::Treasure.new :crowbar, 400
      expect(@player.points).to eq 450

      @player.found_treasure TreasureTrove::Treasure.new :hammer, 50
      expect(@player.points).to eq 500
    end

    context 'strong player' do
      before do
        @player = Player.new 'moe', 150
      end

      it 'should be strong?' do
        expect(@player.strong?).to be_truthy
      end
    end

    context 'weak player' do
      before do
        @player = Player.new 'curly', 50
      end

      it 'should not be strong' do
        expect(@player.strong?).not_to be_truthy
      end
    end

    it 'yields each found treasure and its total points' do
      @player.found_treasure TreasureTrove::Treasure.new :skillet, 100
      @player.found_treasure TreasureTrove::Treasure.new :skillet, 100
      @player.found_treasure TreasureTrove::Treasure.new :hammer, 50
      @player.found_treasure TreasureTrove::Treasure.new :bottle, 5
      @player.found_treasure TreasureTrove::Treasure.new :bottle, 5
      @player.found_treasure TreasureTrove::Treasure.new :bottle, 5
      @player.found_treasure TreasureTrove::Treasure.new :bottle, 5
      @player.found_treasure TreasureTrove::Treasure.new :bottle, 5

      yielded = []
      @player.each_found_treasure do |treasure|
        yielded << treasure
      end

      expect(yielded).to eq [
                                TreasureTrove::Treasure.new(:skillet, 200),
                                TreasureTrove::Treasure.new(:hammer, 50),
                                TreasureTrove::Treasure.new(:bottle, 25)
                            ]
    end
  end
# rubocop: enable Metrics/BlockLength
end
